{ pkgs, ... }:

{
  imports = [
    # Import hardware configuration
    ./hardware-configuration.nix

    # Import modules
    ../../modules/system/default.nix
  ];

  settings = {
    display-manager = "cosmic-greeter";
    desktop-environments = {
      cosmic.enable = true;
      hyprland.enable = true;
    };
    applications = {
      common.enable = true;
      steam.enable = true;
      thunar.enable = true;
    };
    services = {
      docker.enable = true;
      quickemu.enable = true;
      sunshine.enable = false;
      garbage-collection.enable = true;
    };
    hardware = {
      fprint.enable = true;
      printing.enable = true;
      bluetooth.enable = true;
      firewall.enable = true;
      locale.enable = true;
    };
  };

  nix.settings = {
    experimental-features = [ "nix-command" "flakes" ];

    substituters = [
      "https://nix-community.cachix.org"
      "https://cosmic.cachix.org/"
    ];

    trusted-public-keys = [
      "cosmic.cachix.org-1:Dya9IyXD4xdBehWjrkPv6rtxpmMdRel02smYzA85dPE="
    ];
  };

  # Configure hardware
  services.ratbagd.enable = true;

  # Bootloader.
  boot.loader.efi.canTouchEfiVariables = true;
  boot.loader.grub = {
    enable = true;
    efiSupport = true;
    device = "nodev";
    configurationLimit = 32;
  };

  networking.hostName = "xv-laptop"; # Define your hostname.

  users.users.xeovalyte = {
    isNormalUser = true;
    description = "Timo Boomers";
    extraGroups = [ "networkmanager" "wheel" "dialout" ];
  };

  nix.settings.trusted-users = [ "root" "xeovalyte" ];

  # Prevent system freeze on high load
  services.earlyoom = {
    enable = true;
  };

  boot.kernelPackages = pkgs.linuxPackages_latest;

  # Configure wacom tablet
  hardware.opentabletdriver = {
    enable = true;
    package = pkgs.unstable.opentabletdriver;
  };

  services.libinput.enable = true;
  services.fwupd.enable = true;

  system.stateVersion = "24.05";

}
